<?php

namespace Convoy\Http\Middleware\Client\Server;

use Closure;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Convoy\Models\Server;
use Symfony\Component\HttpKernel\Exception\HttpException;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

class ServerNotInstalled
{
    /**
     * Checks that the server is installed before allowing access through the route.
     *
     * @return mixed
     */
    public function handle(Request $request, Closure $next)
    {
        /** @var \Convoy\Models\Server|null $server */
        $server = $request->route()->parameter('server');

        if (!$server instanceof Server) {
            throw new NotFoundHttpException('No server resource was located in the request parameters.');
        }

        if (!$server->isInstalled()) {
            throw new HttpException(Response::HTTP_FORBIDDEN, 'Access to this resource is not allowed due to the current non-installation state.');
        }

        return $next($request);
    }
}
